@@ -63,7 +63,7 @@ pref("general.open_location.last_window_choice", 0);
 pref("general.smoothScroll", false);
 pref("general.autoScroll", true);
 
-pref("general.useragent.extra.seamonkey", "SeaMonkey/2.0");
+pref("general.useragent.extra.seamonkey", "SeaMonkey/2.0.1");
 
 // 0 = blank, 1 = home (browser.startup.homepage), 2 = last
 pref("browser.startup.page",                1);
